Package: gridGraphics
Title: Redraw Base Graphics Using 'grid' Graphics
Version: 0.5-1
Authors@R: c(person("Paul", "Murrell", role = c("cre", "aut"),
                    email = "paul@stat.auckland.ac.nz"),
             person("Zhijian", "Wen", role = "aut",
                    email = "jwen246@aucklanduni.ac.nz"))
Description: Functions to convert a page of plots drawn with the 
  'graphics' package into identical output drawn with the 'grid' package.
  The result looks like the original 'graphics'-based plot, but consists
  of 'grid' grobs and viewports that can then be manipulated with 
  'grid' functions (e.g., edit grobs and revisit viewports).
Depends: grid, graphics
Imports: grDevices
Suggests: magick (>= 1.3), pdftools (>= 1.6)
License: GPL (>= 2)
URL: https://github.com/pmur002/gridgraphics
NeedsCompilation: no
Packaged: 2020-12-10 01:41:04 UTC; pmur002
Author: Paul Murrell [cre, aut],
  Zhijian Wen [aut]
Maintainer: Paul Murrell <paul@stat.auckland.ac.nz>
Repository: CRAN
Date/Publication: 2020-12-13 21:20:03 UTC
Built: R 4.6.0; ; 2026-04-25 16:26:28 UTC; unix
