
importFrom("grDevices",
           "axisTicks", "col2rgb",
           "contourLines", "dev.control", "dev.cur",
           "dev.list", "dev.new", "dev.off", "dev.set", "palette",
           "pdf", "png", "recordPlot", "replayPlot", "rgb", "trans3d")
importFrom("graphics",
           "axTicks", "par", "plot.new")

import("grid")

export("grid.echo", "echoGrob")

# For test code in ./tests/
export("plotdiffInit")
export("plotdiff")
export("plotdiffResult")

S3method("grid.echo", "default")
S3method("grid.echo", "recordedplot")
S3method("grid.echo", "function")

S3method("makeContent", "echogrob")
